@@ -1,12 +1,24 @@
 // [[Rcpp::depends(BH)]]
+// [[Rcpp::plugins(cpp11)]]
 
 #include <Rcpp.h>
 #include <boost/tokenizer.hpp>
 
 using namespace Rcpp;
 
+static int is_ascii_digit(int c) {
+    static const char *s = "0123456789";
+    return strchr(s, c) == NULL ? 0 : 1;
+}
+
+static int is_ascii_punct(int c) {
+    static const char *s = "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~";
+    return strchr(s, c) == NULL ? 0 : 1;
+}
+
 // [[Rcpp::export]]
 List tdm(const StringVector strings,
+         const bool remove_puncts,
          const bool remove_digits,
          const std::vector<std::string> stopwords,
          const std::vector<std::string> dictionary,
@@ -23,17 +35,25 @@ List tdm(const StringVector strings,
 
     for (unsigned int index = 0; index < strings.size(); index++) {
         std::string s = std::string(strings(index));
-        boost::tokenizer<> tok(s);
+        typedef boost::tokenizer<boost::char_separator<char> > tokenizer;
+        boost::char_separator<char> sep(" \f\n\r\t\v");
+        tokenizer tok(s, sep);
 
         line.clear();
-        for (boost::tokenizer<>::iterator it = tok.begin();
+        for (tokenizer::iterator it = tok.begin();
              it != tok.end();
              ++it) {
             std::string token = *it;
-            if (remove_digits)
-                token.erase(
-                        std::remove_if(token.begin(), token.end(), &isdigit),
-                        token.end());
+	    if(remove_puncts)
+		token.erase(std::remove_if(token.begin(),
+					   token.end(),
+					   &is_ascii_punct),
+			    token.end());
+            if(remove_digits)
+                token.erase(std::remove_if(token.begin(),
+					   token.end(),
+					   &is_ascii_digit),
+			    token.end());
             if ((dict.empty() || dict.count(token)) &&
                 min_word_length <= token.length() &&
                 token.length() <= max_word_length &&
@@ -59,6 +79,10 @@ List tdm(const StringVector strings,
         }
     }
 
+    for (const std::string &term : dictionary)
+        if (std::find(terms.begin(), terms.end(), term) == terms.end())
+            terms.push_back(term);
+
     return List::create(Named("i") = i,
                         Named("j") = j,
                         Named("v") = v,
